@@ -4,7 +4,7 @@ import typing as t
 
 
 def _bitbucket_pipelines_url() -> str:
-    return "https://bitbucket.org/atlassianlabs/intellij-bitbucket-references-plugin/raw/master/src/main/resources/schemas/bitbucket-pipelines.schema.json"  # noqa: E501
+    return "https://api.bitbucket.org/schemas/pipelines-configuration"
 
 
 def _githubusercontent_url(owner: str, repo: str, ref: str, path: str) -> str:
@@ -166,6 +166,26 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             "types": "yaml",
         },
     },
+    "meltano": {
+        "url": _githubusercontent_url(
+            "meltano",
+            "meltano",
+            "main",
+            "src/meltano/schemas/meltano.schema.json",
+        ),
+        "hook_config": {
+            "name": "Validate Meltano Config",
+            "description": (
+                "Validate Meltano config against the schema provided by Meltano"
+            ),
+            "files": [
+                r".*meltano\.yml",
+                r"meltano-manifest\.json",
+                r"meltano-manifest\..+\.json",
+            ],
+            "types_or": ["json", "yaml"],
+        },
+    },
     "mergify": {
         "url": "https://docs.mergify.com/mergify-configuration-schema.json",
         "hook_config": {
@@ -212,6 +232,19 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             ],
         },
     },
+    "snapcraft": {
+        "url": _githubusercontent_url(
+            "canonical", "snapcraft", "main", "schema/snapcraft.json"
+        ),
+        "hook_config": {
+            "name": "Validate snapcraft files",
+            "description": (
+                "Validate snapcraft files against the schema provided by Canonical"
+            ),
+            "files": r"^(.+/)?snapcraft\.yaml$",
+            "types": "yaml",
+        },
+    },
     "taskfile": {
         "url": "https://taskfile.dev/schema.json",
         "hook_config": {
